==> rest-sdk-minio-3.2.0.1-sources.jar: cn/herodotus/oss/rest/minio/request/object/SetBucketQuotaRequest.java <==
/*
 * Copyright (c) 2020-2030 码匠君<herodotus@aliyun.com>
 *
 * Dante Cloud licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.apache.org/licenses/LICENSE-2.0>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante OSS 采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改 Dante Cloud 源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.oss.rest.minio.request.object;

import cn.herodotus.engine.assistant.core.definition.domain.Entity;
import cn.herodotus.oss.dialect.minio.enums.QuotaUnitEnums;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotBlank;

/**
 * <p>Description: 设置存储桶配额请求参数实体 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/6/28 16:08
 */
@Schema(name = "设置存储桶配额请求参数实体", title = "设置存储桶配额请求参数实体")
public class SetBucketQuotaRequest implements Entity {

    @Schema(name = "存储桶名称")
    @NotBlank(message = "存储桶名称不能为空")
    private String bucketName;

    @Schema(name = "配额大小")
    @Min(value = 0, message = "配额大小不能小于 0")
    private Long size;

    @Schema(name = "配额单位", description = "配额单位目前支持 KB、MB、GB、TB")
    private QuotaUnitEnums unit = QuotaUnitEnums.MB;

    public String getBucketName() {
        return bucketName;
    }

    public void setBucketName(String bucketName) {
        this.bucketName = bucketName;
    }

    public Long getSize() {
        return size;
    }

    public void setSize(Long size) {
        this.size = size;
    }

    public QuotaUnitEnums getUnit() {
        return unit;
    }

    public void setUnit(QuotaUnitEnums unit) {
        this.unit = unit;
    }
}

==> rest-sdk-minio-3.2.1.7-sources.jar: cn/herodotus/oss/rest/minio/request/object/SetBucketQuotaRequest.java <==
/*
 * Copyright (c) 2020-2030 码匠君<herodotus@aliyun.com>
 *
 * Dante Cloud licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.apache.org/licenses/LICENSE-2.0>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante OSS 采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改 Dante Cloud 源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.oss.rest.minio.request.object;

import cn.herodotus.engine.assistant.definition.domain.base.Entity;
import cn.herodotus.oss.dialect.minio.enums.QuotaUnitEnums;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotBlank;

/**
 * <p>Description: 设置存储桶配额请求参数实体 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/6/28 16:08
 */
@Schema(name = "设置存储桶配额请求参数实体", title = "设置存储桶配额请求参数实体")
public class SetBucketQuotaRequest implements Entity {

    @Schema(name = "存储桶名称")
    @NotBlank(message = "存储桶名称不能为空")
    private String bucketName;

    @Schema(name = "配额大小")
    @Min(value = 0, message = "配额大小不能小于 0")
    private Long size;

    @Schema(name = "配额单位", description = "配额单位目前支持 KB、MB、GB、TB")
    private QuotaUnitEnums unit = QuotaUnitEnums.MB;

    public String getBucketName() {
        return bucketName;
    }

    public void setBucketName(String bucketName) {
        this.bucketName = bucketName;
    }

    public Long getSize() {
        return size;
    }

    public void setSize(Long size) {
        this.size = size;
    }

    public QuotaUnitEnums getUnit() {
        return unit;
    }

    public void setUnit(QuotaUnitEnums unit) {
        this.unit = unit;
    }
}
